Examples in this repository

* [MPRIS to Home Assistant Media Player integration](examples/home_assistant_media_player.md)
* [bluez](examples/bluez.md)
* [Publish dbus2mqtt internal state](examples/dbus2mqtt_internal_state.md)
